@@ -78,7 +78,7 @@ single_mean <- function(
 summary.single_mean <- function(object, dec = 3, ...) {
   cat("Single mean test\n")
   cat("Data      :", object$df_name, "\n")
-  if (!is_empty(object$data_filter)) {
+  if (!radiant.data::is_empty(object$data_filter)) {
     cat("Filter    :", gsub("\\n", "", object$data_filter), "\n")
   }
   cat("Variable  :", object$var, "\n")
